caellion-python-commons: caellion.pycommons.encryption.tripledes Namespace Reference

caellion-python-commons

Classes
caellion.pycommons.encryption.tripledes Namespace Reference

This module provides utilities related to or using 3DES symmetric encryption algorithm. More...

## Classes
class | TripleDESECBMD5Key
| This class provides implementation of triple DES algorithm which uses MD5 hash of password as a key (it uses 16-byte key so it is triple DES with 2 keys) More...

## Detailed Description

This module provides utilities related to or using 3DES symmetric encryption algorithm.